pix_bb library

Classes

Pagador
Pix
PixBB
The main class that provides the Pix Banco do Brasil's API functionalities.
PixPagination
Token
This class represents an OAuth2 access token, which is used for client authentication and authorization.
TransactionParams

Enums

Ambiente

Exceptions / Errors

BBApiException
An exception representing an error response from the BB API.
BBDateException
Exception to represent a date-related error.
BBHttpException
Exception thrown when an HTTP request fails.
BBUnknownException
An exception that represents an unknown error in the Pix BB API.
PixException
The base class for all exceptions related to the Pix feature.