Token class

This class represents an OAuth2 access token, which is used for client authentication and authorization.

Constructors

Token({required String accessToken, required String tokenType, required int expiresIn, required String scope})
const

Properties

accessToken String
The access token string
final
expiresIn int
The lifetime of the access token in seconds
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
The scope of the token, e.g. "pix.read".
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tokenType String
The type of the token, e.g. "Bearer".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited