PixBB class
The main class that provides the Pix Banco do Brasil's API functionalities.
This class encapsulates the operations related to:
- Authentication token management,
- Transaction retrieval.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchTransactions(
{required Token token, DateTimeRange< DateTime> ? dateTimeRange}) → Future<List< Pix> > - Retrieves a list of transactions from the API.
-
getToken(
) → Future< Token> - Retrieves a valid token from the API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited